import JSZip from 'jszip';
import { AnalyzedElementType, ImportedElement, ImportElement, SlideModificationCallback, ShapeModificationCallback } from '../types/types';
import { ISlide } from '../interfaces/islide';
import { IPresentationProps } from '../interfaces/ipresentation-props';
import { PresTemplate } from '../interfaces/pres-template';
import { RootPresTemplate } from '../interfaces/root-pres-template';
import { HelperElement } from '../types/xml-types';
export declare class Slide implements ISlide {
    sourceTemplate: PresTemplate;
    targetTemplate: RootPresTemplate;
    targetNumber: number;
    sourceNumber: number;
    targetArchive: JSZip;
    sourceArchive: JSZip;
    sourcePath: string;
    targetPath: string;
    modifications: SlideModificationCallback[];
    importElements: ImportElement[];
    relsPath: string;
    rootTemplate: RootPresTemplate;
    root: IPresentationProps;
    targetRelsPath: string;
    constructor(params: {
        presentation: IPresentationProps;
        template: PresTemplate;
        slideNumber: number;
    });
    append(targetTemplate: RootPresTemplate): Promise<void>;
    modify(callback: SlideModificationCallback): void;
    addSlideToPresentation(): Promise<void>;
    /**
     * Select and modify a single element on an added slide.
     * @param {string} selector - Element's name on the slide.
     * Should be a unique string defined on the "Selection"-pane within ppt.
     * @param {ShapeModificationCallback | ShapeModificationCallback[]} callback - One or more callback functions to apply.
     * Depending on the shape type (e.g. chart or table), different arguments will be passed to the callback.
     */
    modifyElement(selector: string, callback: ShapeModificationCallback | ShapeModificationCallback[]): this;
    /**
     * Select, insert and (optionally) modify a single element to a slide.
     * @param {string} presName - Filename or alias name of the template presentation.
     * Must have been importet with Automizer.load().
     * @param {number} slideNumber - Slide number within the specified template to search for the required element.
     * @param {ShapeModificationCallback | ShapeModificationCallback[]} callback - One or more callback functions to apply.
     * Depending on the shape type (e.g. chart or table), different arguments will be passed to the callback.
     */
    addElement(presName: string, slideNumber: number, selector: string, callback?: ShapeModificationCallback | ShapeModificationCallback[]): this;
    private addElementToModificationsList;
    importedSelectedElements(): Promise<void>;
    getElementInfo(importElement: ImportElement): Promise<ImportedElement>;
    analyzeElement(sourceElement: XMLDocument, sourceArchive: JSZip, slideNumber: number): Promise<AnalyzedElementType>;
    applyModifications(): Promise<void>;
    copySlideFiles(): Promise<void>;
    copySlideNoteFiles(): Promise<void>;
    updateSlideNoteFile(): Promise<void>;
    appendToSlideRel(rootArchive: JSZip, relId: string, slideCount: number): Promise<HelperElement>;
    appendToSlideList(rootArchive: JSZip, relId: string): Promise<HelperElement>;
    appendSlideToContentType(rootArchive: JSZip, slideCount: number): Promise<HelperElement>;
    appendNotesToContentType(rootArchive: JSZip, slideCount: number): Promise<HelperElement>;
    copyRelatedContent(): Promise<void>;
    hasNotes(): boolean;
}
